==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/de.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
//	german translation: Axel Otterstätter <axel.otterstaetter@googlemail.com>

$mess=array(
"1" => "Konfigurationsdaten",
"2" => "Benutzer",
"3" => "Repositories",
"4" => "Logs",
"5" => "Diagnose",
"6" => "Benutzername",
"7" => "Ist Admin",
"8" => "Markierung Repository",
"9" => "Zugriffstyp",
"10" => "Meta Quelle",
"11" => "Quelle hinzufügen",
"12" => "Meta Plugin",
"13" => "Wollen Sie die Quelle wirklich löschen?",
"14" => "Wahr",
"15" => "Falsch",
"16" => "Datei Datum",
"17" => "Datum",
"18" => "IP",
"19" => "Ebene",
"20" => "Benutzer",
"21" => "Aktion",
"22" => "Param.",
"23" => "Test Name",
"24" => "Test Daten",
"25" => "Repositories Zugriffe",
"26" => "Passwort ändern",
"27" => "Adminrechte",
"28" => "Benutzer hat Adminrechte?",
"29" => "Lesen",
"30" => "Schreiben",
"32" => "Repository-Treiber",
"33" => "Lade...",
"34" => "Soll der Benutzer wirklich gelöscht werden? Dies kann nicht rückgängig gemacht werden!",
"35" => "Soll das Repository wirklich gelöscht werden? Dies kann nicht rückgängig gemacht werden!",
"36" => "Erforderliche Felder fehlen!",
"37" => "Achtung, Passwort und die Wiederholung sind unterschiedlich!",
"38" => "Bitte das Benutzernamefeld ausfüllen!",
"39" => "Bitte beide Passwortfelder ausfüllen!",
"40" => "Bitte zum Zustimmen einen Haken setzen!",
"41" => "Treiberoptionen",
"42" => "Bitte einen Treiber wählen!",
"43" => "Benutzer existiert bereits, bitte einen anderen Anmeldenamen wählen!",
"44" => "Benutzer erfolgreich angelegt",
"45" => "Geänderte Adminrechte von Benutzer ",
"46" => "Rechte geändert von Benutzer ",
"47" => "Daten gespeichert von Benutzer ",
"48" => "Passwort erfolgreich geändert für Benutzer ",
"49" => "Passwort kann nicht geändert werden",
"50" => "Fehler: Ein Repository mit gleichen Namen existiert bereits",
"51" => "Das conf Verzeichnis ist nicht beschreibbar",
"52" => "Repository erfolgreich erstellt",
"53" => "Fehler beim Ändern des Repository",
"54" => "Repository erfolgreich geändert",
"55" => "Achtung, zur Zeit kann nur eine Instanz von jedem Meta Plugin hinzugefügt werden.",
"56" => "Meta Quelle erfolgreich hinzugefügt",
"57" => "Meta Quelle erfolgreich gelöscht",
"58" => "Meta Quelle erfolgreich geändert",
"59" => "Repository erfolgreich gelöscht",
"60" => "Benutzer erfolgreich entfernt",
"61" => "Fehlerhafte Parameter!",
"62" => "Zusammenfassung Rechte",
"63" => "Alle",
"64" => "Rechte der Rolle ändern ",
"65" => "Die Rolle existiert, bitte einen anderen Namen wählen!",
"66" => "Rolle erfolgreich erzeugt",
"67" => "Nicht gefunden wurde Rolle ",
"68" => "Rolle erfolgreich entfernt",
"69" => "Rollen",
"70" => "Benutzer Rollen",
"71" => "Verfügbare Rollen",
"72" => "Drag'n'Drop der Rollen um diese einem Benutzer zuzuweisen",
"73" => "Rolle dem Benutzer hinzugefügt ",
"74" => "Rolle vom Benutzer entfernt ",
"75" => "Neue Rolle",
"role_access" => "o",
"76" => "Rollen ID",
"77" => "Zugriffssteuerung",
"78" => "Persönliche Daten",
"79" => "Repository",
"80" => "Detaillierter Zugriff für diesen Benutzer  (Click on a repository label if you wish to make it the default repository when user logs in)",
"81" => "Typische Repositories Inhalte",
"82" => "Benutzer Batch-editieren",
"83" => "Drag'n'Drop der Rollen um diese allen ausgewählten Benutzern zuzuweisen (Freigegebene Benutzer werden übersprungen)",
"84" => "Benutzer Rollen",
"85" => "Aktionen manuell Filtern",
"86" => "Eine Liste mit kommagetrennten Aktionen die für diese Rolle deaktiviert sind, ohne Einfluss auf die Zugriffsrechte",
"87" => "Aktionen für diese Rolle erfolgreich aktualisiert",
"88" => "Dieses Repository wurde in der Config-Datei angelegt, über das GUI können die Quellen für die Meta-Daten nicht aktualisiert werden.",
"89" => "Spezielle Benutzerdaten",
"90" => "Repository",
"91" => "Vorlagen",
"92" => "Neue Vorlage erstellen",
"93" => "Bearbeiten",
"94" => "Mehrere Bearbeiten",
"95" => "Eine Bezeichnung und einen Treiber für den Datenzugriff wählen (Alle Bereich auf vorgeschriebene Felder prüfen, wenn sich die Maus auf einer Bezeichnung befindet, dann werden weitere Infos angezeigt).",
"96" => "Wenn eine Bezeichnung vergeben und der Treiber ausgewählt wurde, dann aktivieren Sie die Felder die in der Vorlage ausgefüllt sein sollen mit Hilfe der Chexckboxen. Die übrigen Felder kann der Benutzer ändern. Wenn ein Feld aktiviert und leer gelassen wird, dann wird das Feld vor dem Benutzer versteckt.",
"repository_access_key" => "N",
"97" => "Optionen des Plugins erfolgreich aktualisiert",
"98" => "Grundkonfiguration",
"99" => "Plugins",
"100" => "Allgemeine '%s' Plugin-Optionen",
"101" => "Name",
"102" => "Bezeichnung",
"103" => "Beschreibung",
"104" => "Aktiv",
"105" => "Automatic checks",
"106" => "Unique Identifier",
"107" => "Plugin Configurations",
"108" => "Documentation",
"109" => "Global Configurations",
"110" => "Repositories & Users",
"111" => "Logs & Other Data",
"112" => "<b>Apply this role by default</b> to all new users.",
"113" => "Role status was successfully modified",
"114" => "Default",
"115" => "Scheme",
    "116" => "Template Label",
    "117" => "Template Driver",
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/access.ajxp_conf/i18n/de.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
//	german translation: Axel Otterstätter <axel.otterstaetter@googlemail.com>

$mess=array(
"1" => "Konfigurationsdaten",
"2" => "Benutzer",
"3" => "Repositories",
"4" => "Logs",
"5" => "Diagnose",
"6" => "Benutzername",
"7" => "Ist Admin",
"8" => "Markierung Repository",
"9" => "Zugriffstyp",
"10" => "Meta Quelle",
"11" => "Quelle hinzufügen",
"12" => "Meta Plugin",
"13" => "Wollen Sie die Quelle wirklich löschen?",
"14" => "Wahr",
"15" => "Falsch",
"16" => "Datei Datum",
"17" => "Datum",
"18" => "IP",
"19" => "Ebene",
"20" => "Benutzer",
"21" => "Aktion",
"22" => "Param.",
"23" => "Test Name",
"24" => "Test Daten",
"25" => "Repositories Zugriffe",
"26" => "Passwort ändern",
"27" => "Adminrechte",
"28" => "Benutzer hat Adminrechte?",
"29" => "Lesen",
"30" => "Schreiben",
"32" => "Repository-Treiber",
"33" => "Lade...",
"34" => "Soll der Benutzer wirklich gelöscht werden? Dies kann nicht rückgängig gemacht werden!",
"35" => "Soll das Repository wirklich gelöscht werden? Dies kann nicht rückgängig gemacht werden!",
"36" => "Erforderliche Felder fehlen!",
"37" => "Achtung, Passwort und die Wiederholung sind unterschiedlich!",
"38" => "Bitte das Benutzernamefeld ausfüllen!",
"39" => "Bitte beide Passwortfelder ausfüllen!",
"40" => "Bitte zum Zustimmen einen Haken setzen!",
"41" => "Treiberoptionen",
"42" => "Bitte einen Treiber wählen!",
"43" => "Benutzer existiert bereits, bitte einen anderen Anmeldenamen wählen!",
"44" => "Benutzer erfolgreich angelegt",
"45" => "Geänderte Adminrechte von Benutzer ",
"46" => "Rechte geändert von Benutzer ",
"47" => "Daten gespeichert von Benutzer ",
"48" => "Passwort erfolgreich geändert für Benutzer ",
"49" => "Passwort kann nicht geändert werden",
"50" => "Fehler: Ein Repository mit gleichen Namen existiert bereits",
"51" => "Das conf Verzeichnis ist nicht beschreibbar",
"52" => "Repository erfolgreich erstellt",
"53" => "Fehler beim Ändern des Repository",
"54" => "Repository erfolgreich geändert",
"55" => "Achtung, zur Zeit kann nur eine Instanz von jedem Meta Plugin hinzugefügt werden.",
"56" => "Meta Quelle erfolgreich hinzugefügt",
"57" => "Meta Quelle erfolgreich gelöscht",
"58" => "Meta Quelle erfolgreich geändert",
"59" => "Repository erfolgreich gelöscht",
"60" => "Benutzer erfolgreich entfernt",
"61" => "Fehlerhafte Parameter!",
"62" => "Zusammenfassung Rechte",
"63" => "Alle",
"64" => "Rechte der Rolle ändern ",
"65" => "Die Rolle existiert, bitte einen anderen Namen wählen!",
"66" => "Rolle erfolgreich erzeugt",
"67" => "Nicht gefunden wurde Rolle ",
"68" => "Rolle erfolgreich entfernt",
"69" => "Rollen",
"70" => "Benutzer Rollen",
"71" => "Verfügbare Rollen",
"72" => "Drag'n'Drop der Rollen um diese einem Benutzer zuzuweisen",
"73" => "Rolle dem Benutzer hinzugefügt ",
"74" => "Rolle vom Benutzer entfernt ",
"75" => "Neue Rolle",
"role_access" => "o",
"76" => "Rollen ID",
"77" => "Zugriffssteuerung",
"78" => "Persönliche Daten",
"79" => "Repository",
"80" => "Detaillierter Zugriff für diesen Benutzer  (Click on a repository label if you wish to make it the default repository when user logs in)",
"81" => "Typische Repositories Inhalte",
"82" => "Benutzer Batch-editieren",
"83" => "Drag'n'Drop der Rollen um diese allen ausgewählten Benutzern zuzuweisen (Freigegebene Benutzer werden übersprungen)",
"84" => "Benutzer Rollen",
"85" => "Aktionen manuell Filtern",
"86" => "Eine Liste mit kommagetrennten Aktionen die für diese Rolle deaktiviert sind, ohne Einfluss auf die Zugriffsrechte",
"87" => "Aktionen für diese Rolle erfolgreich aktualisiert",
"88" => "Dieses Repository wurde in der Config-Datei angelegt, über das GUI können die Quellen für die Meta-Daten nicht aktualisiert werden.",
"89" => "Spezielle Benutzerdaten",
"90" => "Repository",
"91" => "Vorlagen",
"92" => "Neue Vorlage erstellen",
"93" => "Bearbeiten",
"94" => "Mehrere Bearbeiten",
"95" => "Eine Bezeichnung und einen Treiber für den Datenzugriff wählen (Alle Bereich auf vorgeschriebene Felder prüfen, wenn sich die Maus auf einer Bezeichnung befindet, dann werden weitere Infos angezeigt).",
"96" => "Wenn eine Bezeichnung vergeben und der Treiber ausgewählt wurde, dann aktivieren Sie die Felder die in der Vorlage ausgefüllt sein sollen mit Hilfe der Chexckboxen. Die übrigen Felder kann der Benutzer ändern. Wenn ein Feld aktiviert und leer gelassen wird, dann wird das Feld vor dem Benutzer versteckt.",
"repository_access_key" => "N",
"97" => "Optionen des Plugins erfolgreich aktualisiert",
"98" => "Grundkonfiguration",
"99" => "Plugins",
"100" => "Allgemeine '%s' Plugin-Optionen",
"101" => "Name",
"102" => "Bezeichnung",
"103" => "Beschreibung",
"104" => "Aktiv",
"105" => "Automatik Checks",
"106" => "Einmalige ID",
"107" => "Plugin Konfigurationen",
"108" => "Dokumentation",
"109" => "Globale Konfigurationen",
"110" => "Repositories & Benutzer",
"111" => "Logs & Andere Daten",
"112" => "<b>Diese Rolle als Standard festlegen</b> für alle neuen Benutzer.",
"113" => "Der Status der Rolle wurde erfogreich geändert",
"114" => "Standard",
"115" => "Schema",
"116" => "Template Label",
"117" => "Template Driver",
"118" => "Neue Gruppe",
"group_access" => "G",
"119" => "Set user group",

);
